Module codes

Module codes 

Structs

ChunksIter
Returns ranges of nodes to process in parallel of size chunk_size each, with the last chunk possibly being smaller. The equivalent of std::iter::Chunks but with a Range instead of a Slice.
CliArgs

Functions

compare_codes
Prints the statistics of how much the optimal codes improve over the reference ones.
main
optimize_codes