pub fn compare_codes(stats: &DecoderStats, reference: CompFlags, top_k: usize)Expand description
Prints the statistics of how much the optimal codes improve over the reference ones.
pub fn compare_codes(stats: &DecoderStats, reference: CompFlags, top_k: usize)Prints the statistics of how much the optimal codes improve over the reference ones.