pub struct CliArgs {
pub basename: PathBuf,
pub random: Option<usize>,
pub repeats: usize,
pub first: bool,
pub _static: bool,
pub degrees: bool,
pub check: bool,
pub slice: bool,
}Fields
basename: PathBufThe basename of the graph.
random: Option<usize>Perform a random-access test on this number of randomly selected nodes.
repeats: usizeThe number of repeats.
first: boolIn random-access tests, test just access to the first successor.
_static: boolStatic dispatch for speed tests (default BvGraph parameters).
degrees: boolTest sequential high-speed offset/degree scanning.
check: boolDo not test speed, but check that the sequential and random-access successor lists are the same.
slice: boolExpand offsets into a slice of usize before testing random-access successor lists.