pub struct CliArgs {
pub basename: PathBuf,
pub symm: bool,
pub transposed: Option<PathBuf>,
pub centralities: Centralities,
pub log2m: usize,
pub upper_bound: usize,
pub threshold: Option<f64>,
pub num_threads: NumThreadsArg,
pub granularity: GranularityArgs,
pub seed: u64,
}Fields
basename: PathBufThe basename of the graph.
symm: boolWhether the graph is symmetric or not. If true, the algorithm will use the graph as its transposed.
transposed: Option<PathBuf>The basename of the transposed graph. If available, HyperBall will perform systolic iterations which will speed up the computation. If the graph is symmetric, use the –symm option instead.
centralities: Centralitieslog2m: usizeThe base-2 logarithm of the number of registers for the HyperLogLog cardinality estimators.
upper_bound: usizeMaximum number of iterations to run.
threshold: Option<f64>A value that will be used to stop the computation by relative increment if the neighborhood function is being computed. Otherwise, the computation will stop when all estimators do not change their values.
num_threads: NumThreadsArggranularity: GranularityArgsseed: u64The seed of the pseudorandom number generator used for initialization.